@@ -5,6 +5,10 @@
 
 from pyutils_spirit.spirit_container.annotation import Get, Post, Put, Delete
 
+from pyutils_spirit.spirit_container.multipart_file import MultipartFile
+
+from pyutils_spirit.spirit_container.request_result import Result
+
 from pyutils_spirit.spirit_container.spirit_application import (SpiritApplication,
                                                                 Component,
                                                                 Mapper,
@@ -16,6 +20,8 @@ __all__ = ["Get",
            "Post",
            "Put",
            "Delete",
+           'MultipartFile',
+           'Result',
            "SpiritApplication",
            "Component",
            "Mapper",
