@@ -4,8 +4,6 @@
 # @Filename: spirit_application.py
 import os
 
-import cgi
-
 import json
 
 import inspect
@@ -16,6 +14,8 @@ from threading import Lock
 
 from typing import Callable
 
+from cgi import FieldStorage
+
 from types import FunctionType, MethodType
 
 from pyutils_spirit.style import draw_spirit_banner
@@ -38,7 +38,7 @@ basicConfig(level=INFO)
 class SpiritApplication:
     start_status: bool = None
 
-    unified_response_type: bool = None
+    __unified_response_type__: bool = None
 
     __unique_modules: Set[object] = None
 
@@ -58,13 +58,13 @@ class SpiritApplication:
 
     __lock: Lock = None
 
-    controller_paths_set: set[str] = None
+    __controller_paths_set: set[str] = None
 
-    interceptor_paths_set: set[str] = None
+    __interceptor_paths_set: set[str] = None
 
-    interceptor_function_before: Callable[[BaseHTTPRequestHandler], tuple[bool, int]] = None
+    __interceptor_function_before__: Callable[[BaseHTTPRequestHandler], tuple[int, bool]] = None
 
-    interceptor_function_after: Callable[[BaseHTTPRequestHandler], None] = None
+    __interceptor_function_after__: Callable[[BaseHTTPRequestHandler], None] = None
 
     def __init__(self, __file__):
         SpiritApplication.__lock = Lock()
@@ -74,8 +74,8 @@ class SpiritApplication:
         SpiritApplication.__container = HashAssemble()
         self.__auto_wired_set__ = set()
         SpiritApplication.__method_types = ("GET", "POST", "PUT", "DELETE")
-        SpiritApplication.controller_paths_set = set()
-        SpiritApplication.interceptor_paths_set = set()
+        SpiritApplication.__controller_paths_set = set()
+        SpiritApplication.__interceptor_paths_set = set()
 
     def start(self, host: str, port: int, unified_response_type: bool = True):
         SpiritApplication.__lock.acquire()
@@ -85,7 +85,7 @@ class SpiritApplication:
             SpiritApplication.start_status = True
         finally:
             SpiritApplication.__lock.release()
-        SpiritApplication.unified_response_type = unified_response_type
+        SpiritApplication.__unified_response_type__ = unified_response_type
         draw_spirit_banner()
         self.__current_work_dir__ = os.getcwd()
         self.__scan_modules(self.__current_work_dir__)
@@ -118,14 +118,13 @@ class SpiritApplication:
                 self.__unique_modules.add(obj)
                 if obj is None:
                     continue
-                print(name, obj, getattr(obj, "__decorator__", None))
-                if isinstance(obj, FunctionType):
+                if isinstance(obj, FunctionType | type):
                     decorator = getattr(obj, "__decorator__", None)
                     if decorator in SpiritApplication.__signatures:
                         self.__auto_wired_set__.add(obj())
                         if decorator == "Controller":
                             params = getattr(obj, "__decorator_params__")
-                            SpiritApplication.controller_paths_set.add(params)
+                            SpiritApplication.__controller_paths_set.add(params)
 
     def __auto_injected(self) -> None:
         for instance in self.__auto_wired_set__:
@@ -147,31 +146,29 @@ class SpiritApplication:
 
     @classmethod
     def set_interceptor_paths(cls, interceptor_paths: set[str]) -> None:
-        cls.interceptor_paths_set = interceptor_paths
+        cls.__interceptor_paths_set = interceptor_paths
 
     @classmethod
     def set_interceptor_before_function(cls,
                                         interceptor_before_function:
-                                        Callable[[BaseHTTPRequestHandler], tuple[bool, int]]) -> None:
-        cls.interceptor_function_before = interceptor_before_function
+                                        Callable[[BaseHTTPRequestHandler], tuple[int, bool]]) -> None:
+        cls.__interceptor_function_before__ = interceptor_before_function
 
     @classmethod
     def set_interceptor_after_function(cls,
                                        interceptor_after_function:
                                        Callable[[BaseHTTPRequestHandler], None]) -> None:
-        cls.interceptor_after_function = interceptor_after_function
+        cls.__interceptor_function_after__ = interceptor_after_function
 
     @classmethod
     def __do_interceptor_function__(cls, request_path: str) -> bool:
-        if len(cls.interceptor_paths_set) == 0:
+        if len(cls.__interceptor_paths_set) == 0:
             return False
-        for path in cls.interceptor_paths_set:
+        for path in cls.__interceptor_paths_set:
             path_list = request_path.split(path, maxsplit=1)
             if len(path_list) == 1:
                 return False
-            if path_list[0] == "":
-                return True
-            if path_list[1][0] == "?":
+            if path_list[0] == "" and path_list[1][0] == "?":
                 return True
         return False
 
@@ -179,7 +176,7 @@ class SpiritApplication:
     def get_func_kwargs(cls, path: str, method_type: str) -> [object, callable, dict]:
         cls.__lock.acquire()
         try:
-            for controller_path in cls.controller_paths_set:
+            for controller_path in cls.__controller_paths_set:
                 path_list = path.split(controller_path, maxsplit=1)
                 if len(path_list) == 1:
                     continue
@@ -230,17 +227,17 @@ class SpiritApplication:
             self.__response_code__ = 500
             self.__response__ = str(e)
             if isinstance(e, BusinessException):
-                if SpiritApplication.unified_response_type is True:
+                if SpiritApplication.__unified_response_type__ is True:
                     self.__response__ = Result.WARN(self.__response__)
             else:
-                if SpiritApplication.unified_response_type is True:
+                if SpiritApplication.__unified_response_type__ is True:
                     self.__response__ = Result.ERROR(self.__response__)
 
         def __is_interceptor_func__(self):
             self.__is_interceptor__ = SpiritApplication.__do_interceptor_function__(self.path)
             if self.__is_interceptor__:
-                if SpiritApplication.interceptor_function_before is not None:
-                    self.__is_pass__, self.__response_code__ = SpiritApplication.interceptor_function_before(self)
+                if SpiritApplication.__interceptor_function_before__ is not None:
+                    self.__response_code__, self.__is_pass__ = SpiritApplication.__interceptor_function_before__(self)
                     if self.__is_pass__ is False:
                         self.__response__ = Result.WARN(f"the request '{self.path}' is be intercepted")
                         return True
@@ -253,8 +250,8 @@ class SpiritApplication:
             self.end_headers()
             self.wfile.write(json.dumps(self.__response__).encode('utf-8'))
             if self.__is_interceptor__ and self.__is_pass__:
-                if SpiritApplication.interceptor_function_after is not None:
-                    SpiritApplication.interceptor_function_after(self)
+                if SpiritApplication.__interceptor_function_after__ is not None:
+                    SpiritApplication.__interceptor_function_after__(self)
 
         def do_OPTIONS(self):
             self.send_response(200)
@@ -272,7 +269,7 @@ class SpiritApplication:
                     self.__response__ = func(*kwargs)
                 else:
                     self.__response__ = func()
-                if SpiritApplication.unified_response_type is True:
+                if SpiritApplication.__unified_response_type__ is True:
                     self.__response__ = Result.SUCCESS(self.__response__)
             except Exception as e:
                 self.__request_exception_advice__(e)
@@ -282,9 +279,15 @@ class SpiritApplication:
         def __get_post_file__(self, post_body_length):
             if self.headers['Content-Type'].startswith('multipart/form-data'):
                 # 解析请求体
-                form = cgi.FieldStorage(fp=self.rfile,
-                                        headers=self.headers,
-                                        environ={'REQUEST_METHOD': 'POST'})
+                form = FieldStorage(fp=self.rfile,
+                                    headers=self.headers,
+                                    environ={'REQUEST_METHOD': 'POST'})
+                for fs in form.list:
+                    print(fs)
+                    print(fs.name)
+                    print(fs.filename)
+                    print(type(fs.value), type(form.getvalue("data", None)))
+                    print(isinstance(fs.value, bytes))
                 # 处理文件
                 if "file" in form:
                     temp_file_handler = form["file"]
@@ -316,7 +319,7 @@ class SpiritApplication:
                     self.__response__ = func(*kwargs, self.__data__)
                 else:
                     self.__response__ = func(self.__data__)
-                if SpiritApplication.unified_response_type is True:
+                if SpiritApplication.__unified_response_type__ is True:
                     self.__response__ = Result.SUCCESS(self.__response__)
             except Exception as e:
                 self.__request_exception_advice__(e)
@@ -346,7 +349,7 @@ class SpiritApplication:
                         self.__response__ = func()
                     else:
                         self.__response__ = func(self.__data__)
-                if SpiritApplication.unified_response_type is True:
+                if SpiritApplication.__unified_response_type__ is True:
                     self.__response__ = Result.SUCCESS(self.__response__)
             except Exception as e:
                 self.__request_exception_advice__(e)
@@ -378,7 +381,7 @@ class SpiritApplication:
                         self.__response__ = func()
                     else:
                         self.__response__ = func(self.__data__)
-                if SpiritApplication.unified_response_type is True:
+                if SpiritApplication.__unified_response_type__ is True:
                     self.__response__ = Result.SUCCESS(self.__response__)
             except Exception as e:
                 self.__request_exception_advice__(e)
