@@ -11,6 +11,8 @@ import base64
 
 import hashlib
 
+from abc import ABC
+
 from pyutils_spirit.style import draw_websocket_banner
 
 from logging import info, basicConfig, INFO, exception
@@ -22,9 +24,7 @@ from pyutils_spirit.concurrent_thread import ThreadExecutor
 basicConfig(level=INFO)
 
 
-class WebSocket:
-    __web_sockets_assemble: Assemble[str, object] = None
-
+class WebSocket(ABC):
     __socket_server: socket.socket = None
 
     __listener_count = None
@@ -51,7 +51,6 @@ class WebSocket:
 
     @classmethod
     def __start_server(cls, host, port, other_cls):
-        cls.__web_sockets_assemble = HashAssemble()
         cls.__socket_server = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
         cls.__listener_count = 127
         cls.__buffer_size = 1024
@@ -226,31 +225,17 @@ class WebSocket:
         cls.__instance_assemble.remove(address)
 
     @classmethod
-    def WebSocketServer(cls, host: str, port: int):
+    def WebSocketServer(cls, host: str, port: int) -> callable:
 
-        def decorator_handler(other_cls) -> callable:
+        def decorator_handler(other_cls) -> type:
             draw_websocket_banner()
             cls.__start_server(host, port, other_cls)
-
             other_cls.__decorator__ = "WebSocketServer"
             other_cls.__decorator_params__ = {
                 "host": host,
                 "port": port
             }
-
-            # def get_websocket_instance(*args, **kwargs) -> object:
-            #     instance = cls.__web_sockets_assemble.get(f"{host}:{port}")
-            #     if instance is None:
-            #         instance = other_cls(*args, **kwargs)
-            #         cls.__web_sockets_assemble.put(f"{host}:{port}", instance)
-            #         return instance
-            #
-            # get_websocket_instance.__decorator__ = "WebSocketServer"
-            # get_websocket_instance.__decorator_params__ = {
-            #     "host": host,
-            #     "port": port
-            # }
-            # return get_websocket_instance
+            return other_cls
 
         return decorator_handler
 
