@@ -11,8 +11,6 @@ from pyutils_spirit.util.queue import Queue, LinkedQueue, BlockingQueue
 
 from pyutils_spirit.util.set import Set, HashSet
 
-from pyutils_spirit.util.thread_executor import ThreadExecutor
-
 __all__ = ['Assemble',
            'HashAssemble',
            'ReentryLock',
@@ -21,5 +19,4 @@ __all__ = ['Assemble',
            'LinkedQueue',
            'BlockingQueue',
            'Set',
-           'HashSet',
-           'ThreadExecutor']
+           'HashSet']
